

.. zgw_consumers documentation master file, created by startproject.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to zgw_consumers's documentation!
=================================================

:Version: 0.9.0.dev9
:Source: https://github.com/maykinmedia/zgw_consumers
:Keywords: ``<keywords>``
:PythonVersion: 3.6

|build-status| |requirements| |coverage|

|python-versions| |django-versions| |pypi-version|

<One liner describing the project>

.. contents::

.. section-numbering::

Features
========

* ...
* ...

Installation
============

Requirements
------------

* Python 3.6 or above
* setuptools 30.3.0 or above
* Django 1.11 or above


Install
-------

.. code-block:: bash

    pip install zgw_consumers


Usage
=====

<document or refer to docs>



.. |build-status| image:: https://travis-ci.org/maykinmedia/zgw_consumers.svg?branch=develop
    :target: https://travis-ci.org/maykinmedia/zgw_consumers

.. |requirements| image:: https://requires.io/github/maykinmedia/zgw_consumers/requirements.svg?branch=develop
    :target: https://requires.io/github/maykinmedia/zgw_consumers/requirements/?branch=develop
    :alt: Requirements status

.. |coverage| image:: https://codecov.io/gh/maykinmedia/zgw_consumers/branch/develop/graph/badge.svg
    :target: https://codecov.io/gh/maykinmedia/zgw_consumers
    :alt: Coverage status

.. |python-versions| image:: https://img.shields.io/pypi/pyversions/zgw_consumers.svg

.. |django-versions| image:: https://img.shields.io/pypi/djversions/zgw_consumers.svg

.. |pypi-version| image:: https://img.shields.io/pypi/v/zgw_consumers.svg
    :target: https://pypi.org/project/zgw_consumers/
